smartcard.pcsc.PCSCExceptions.BaseSCardException

# ``smartcard`.`pcsc`.`PCSCExceptions`.`BaseSCardException``

exception documentation

`class BaseSCardException(Exception):`

Known subclasses: `smartcard.pcsc.PCSCExceptions.AddReaderToGroupException`, `smartcard.pcsc.PCSCExceptions.EstablishContextException`, `smartcard.pcsc.PCSCExceptions.IntroduceReaderException`, `smartcard.pcsc.PCSCExceptions.ListReadersException`, `smartcard.pcsc.PCSCExceptions.ReleaseContextException`, `smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException`

View In Hierarchy

Base class for scard (aka PCSC) exceptions.

scard exceptions are raised by the scard module, i.e. low-level PCSC access to readers and cards.

Method | `__init__` | Constructor that stores the pcsc error status.
Method | `__str__` | Returns a string representation of the exception.
Instance Variable | `hresult` | Undocumented
Instance Variable | `message` | Undocumented

def __init__(self, hresult=-1, message='', *args):
overridden in `smartcard.pcsc.PCSCExceptions.AddReaderToGroupException`, `smartcard.pcsc.PCSCExceptions.EstablishContextException`, `smartcard.pcsc.PCSCExceptions.IntroduceReaderException`, `smartcard.pcsc.PCSCExceptions.ListReadersException`, `smartcard.pcsc.PCSCExceptions.ReleaseContextException`, `smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException`

Constructor that stores the pcsc error status.

def __str__(self):

Returns a string representation of the exception.

hresult =

Undocumented

message =

Undocumented